@@ -13,7 +13,7 @@ import {
   shaders
 } from './shaders';
 
-import THREE from 'three.js';
+import * as THREE from 'three';
 // import Stats from "https://cdnjs.cloudflare.com/ajax/libs/stats.js/r16/Stats.min";
 import dat from 'dat.gui';
 
@@ -50,12 +50,12 @@ import dat from 'dat.gui';
       defines["FRAGMENT_SHADER"] = true;
     var s ="";
     for(var key in defines)
-      s += "#define " + key + " " + defines[key] + "\\n"
+      s += "#define " + key + " " + defines[key] + "\n"
 
 
     var utils = window.atob(shaders['utils.h']);
     var shader = window.atob(shaders[name]).trim();
-    return s + "// START FILE: utils.h \\n" + utils +'\\n// START FILE: ' + name + "\\n" + shader;
+    return s + "// START FILE: utils.h \n" + utils +'\n// START FILE: ' + name + "\n" + shader;
   }
 
 
@@ -339,10 +339,10 @@ import dat from 'dat.gui';
 
 
   class Scene {
-    scene: THREE.Mesh;
-    renderer: THREE.Renderer;
-    camera: THREE.Camera;
-    ortho_camera: THREE.Camera;
+    scene: THREE.Scene;
+    renderer: THREE.WebGLRenderer;
+    camera: THREE.PerspectiveCamera;
+    ortho_camera: THREE.OrthographicCamera;
     clipping_plane: THREE.Vector4;
     three_clipping_plane: THREE.Plane;
     world_clipping_plane: THREE.Plane;
@@ -358,13 +358,13 @@ import dat from 'dat.gui';
     gui_functions: any;
     uniforms: any;
 
-    colormap_object: THREE.Mesh;
-    wireframe_object: THREE.Mesh;
+    colormap_object: any;
+    wireframe_object: THREE.Line;
     mesh_object: THREE.Mesh;
     clipping_function_object: THREE.Mesh;
     clipping_vectors_object: THREE.Mesh;
-    axes_object: THREE.Mesh;
-    center_tag: THREE.Mesh;
+    axes_object: any;
+    center_tag: any;
 
     is_complex: boolean;
     context: any;
@@ -377,18 +377,18 @@ import dat from 'dat.gui';
     c_cmin: any;
     c_cmax: any;
 
-    buffer_scene: THREE.Mesh;
+    buffer_scene: THREE.Scene;
     buffer_object: THREE.Mesh;
-    buffer_camera: THREE.Camera;
+    buffer_camera: THREE.OrthographicCamera;
     buffer_texture: any;
 
     mesh_center: THREE.Vector3;
-    mesh_radius: THREE.number;
+    mesh_radius: number;
 
     requestId: number;
     have_webgl2: boolean;
 
-    pivot: THREE.Object;
+    pivot: THREE.Group;
 
     have_deformation: boolean;
     have_z_deformation: boolean;
@@ -473,7 +473,7 @@ import dat from 'dat.gui';
         const x0 = -aspect*0.93;
         const y0 = 0.93;
         this.colormap_object.position.set(x0, 0.95, 0.0);
-        this.colormap_object.updateWorldMatrix();
+        this.colormap_object.updateWorldMatrix( false, false );
 
         const n = this.colormap_labels.length;
         const y = Math.round(0.5*(0.05+0.07)*h);
@@ -551,7 +551,7 @@ import dat from 'dat.gui';
       let r = this.mesh_radius;
       this.buffer_camera = new THREE.OrthographicCamera( -r, r, r, -r, -10, 10 );
 
-      const geo = this.clipping_vectors_object.geometry;
+      const geo = <THREE.InstancedBufferGeometry>this.clipping_vectors_object.geometry;
       var arrowid = new Float32Array(2*n * n);
       for(var i=0; i<n; i++)
         for(var j=0; j<n; j++) {
@@ -972,7 +972,10 @@ import dat from 'dat.gui';
       }
 
       if(this.colormap_object != null)
-        this.colormap_object.material.map = this.colormap_texture;
+      {
+        let material = <THREE.MeshBasicMaterial>this.colormap_object.material;
+        material.map = this.colormap_texture;
+      }
 
       this.animate();
     }
@@ -1140,7 +1143,7 @@ import dat from 'dat.gui';
     {
       if(this.wireframe_object != null)
       {
-        let geo = this.wireframe_object.geometry;
+        let geo = <THREE.InstancedBufferGeometry>this.wireframe_object.geometry;
         const n_verts = render_data.Bezier_points[0].length/3/4*3/4; // 3 components, 3/4 b64 ratio, 4 bytes per float
         geo.setAttribute( 'p0', new THREE.InstancedBufferAttribute( readB64( render_data.Bezier_points[0]), 3 ));
         geo.setAttribute( 'p1', new THREE.InstancedBufferAttribute( readB64( render_data.Bezier_points[1]), 3 ));
@@ -1155,7 +1158,7 @@ import dat from 'dat.gui';
 
       if(this.mesh_object != null)
       {
-        let geo = this.mesh_object.geometry;
+        let geo = <THREE.InstancedBufferGeometry>this.mesh_object.geometry;
         const data = render_data.Bezier_trig_points;
         const order = render_data.order2d;
 
@@ -1184,7 +1187,7 @@ import dat from 'dat.gui';
 
       if(this.clipping_function_object != null)
       {
-        let geo = this.clipping_function_object.geometry;
+        let geo = <THREE.InstancedBufferGeometry>this.clipping_function_object.geometry;
 
         let names = [ 'p0', 'p1', 'p2', 'p3' ];
         if(render_data.order3d==2)
@@ -1300,7 +1303,8 @@ import dat from 'dat.gui';
         if(gui_status.subdivision !== undefined)
         {
           uniforms.n_segments.value = subdivision;
-          this.wireframe_object.geometry.setDrawRange(0, subdivision+1)
+          let geo = <THREE.BufferGeometry>this.wireframe_object.geometry;
+          geo.setDrawRange(0, subdivision+1);
         }
       }
 
@@ -1310,7 +1314,8 @@ import dat from 'dat.gui';
         if(gui_status.subdivision !== undefined)
         {
           uniforms.n_segments.value = subdivision;
-          this.mesh_object.geometry.setDrawRange(0, 3*subdivision*subdivision)
+          let geo = <THREE.BufferGeometry>this.mesh_object.geometry;
+          geo.setDrawRange(0, 3*subdivision*subdivision)
         }
       }
 
@@ -1319,7 +1324,8 @@ import dat from 'dat.gui';
       {
         uniforms.n_segments.value = subdivision;
         const sd = subdivision;
-        this.clipping_function_object.geometry.setDrawRange(0, 6*sd*sd*sd)
+        let geo = <THREE.BufferGeometry>this.clipping_function_object.geometry;
+        geo.setDrawRange(0, 6*sd*sd*sd);
         this.clipping_function_object.visible = gui_status.Clipping.function && gui_status.Clipping.enable;
       }
 
